@@ -2,7 +2,7 @@
 
 package Dancer::Plugin::Authorize;
 BEGIN {
-  $Dancer::Plugin::Authorize::VERSION = '0.1001';
+  $Dancer::Plugin::Authorize::VERSION = '0.1010';
 }
 use strict;
 use warnings;
@@ -40,7 +40,11 @@ sub new {
             error => []
         };
     }
+    
     session 'user' => $user;
+    
+    return $credentialsClass->new unless scalar @_;
+    
     my $self = {};
     bless $self, $class;
     return $credentialsClass->new->authorize($settings->{credentials}->{options}, @_)
@@ -117,7 +121,7 @@ Dancer::Plugin::Authorize - Dancer Authentication, Security and Role-Based Acces
 
 =head1 VERSION
 
-version 0.1001
+version 0.1010
 
 =head1 SYNOPSIS
 
@@ -170,9 +174,10 @@ The Dancer::Plugin::Authorize authentication framework relies on the
 L<Dancer::Plugin::Authorize::Credentials> namespace to do the actual
 authentication, and likewise relies on the L<Dancer::Plugin::Authorize::Permissions>
 namespace to handle access control. The following configuration example is based on
-L<Dancer::Plugin::Authorize::Credentials::Config> and L<Dancer::Plugin::Authorize::Permissions>.
+L<Dancer::Plugin::Authorize::Credentials::Config> and L<Dancer::Plugin::Authorize::Permissions::Config>.
 This framework also ship with L<Dancer::Plugin::Authorize::Credentials::SQLite>,
-L<Dancer::Plugin::Authorize::Credentials::MySQL>, L<Dancer::Plugin::Authorize::Credentials::PostrgeSQL>.
+L<Dancer::Plugin::Authorize::Credentials::MySQL>, L<Dancer::Plugin::Authorize::Credentials::PostrgeSQL>
+which are arguably easier to setup and utilize.
 
 =head1 CONFIGURATION
 
