@@ -2,7 +2,7 @@
 
 package Dancer::Plugin::Authorize::Credentials::PostgreSQL;
 BEGIN {
-  $Dancer::Plugin::Authorize::Credentials::PostgreSQL::VERSION = '0.1001';
+  $Dancer::Plugin::Authorize::Credentials::PostgreSQL::VERSION = '0.1010';
 }
 
 use strict;
@@ -25,7 +25,7 @@ sub authorize {
         
         unless ($password) {
             $self->errors('login and password are required');
-            return 0;
+            return undef;
         }
         
         my $sth = database($options->{handle})->prepare(
@@ -53,6 +53,7 @@ sub authorize {
         }
         else {
             $self->errors('login and/or password is invalid');
+            return undef;
         }
     
     }
@@ -68,6 +69,7 @@ sub authorize {
         }
         else {
             $self->errors('you are not authorized', 'your session may have ended');
+            return undef;
         }
         
     }
@@ -84,7 +86,7 @@ Dancer::Plugin::Authorize::Credentials::PostgreSQL - Dancer::Plugin::Authorize a
 
 =head1 VERSION
 
-version 0.1001
+version 0.1010
 
 =head1 SYNOPSIS
 
